Class: Google::Apis::NotebooksV2::AIPlatformNotebooksService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::NotebooksV2::AIPlatformNotebooksService
- Defined in:
- lib/google/apis/notebooks_v2/service.rb
Overview
Notebooks API
Notebooks API is used to manage notebook resources in Google Cloud.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://notebooks.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Empty
Starts asynchronous cancellation on a long-running operation.
-
#check_instance_authorization(name, check_authorization_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::CheckAuthorizationResponse
Initiated by Cloud Console for Oauth consent flow for Workbench Instances.
-
#check_project_location_instance_upgradability(notebook_instance, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::CheckInstanceUpgradabilityResponse
Checks whether a notebook instance is upgradable.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Creates a new Instance in a given project and location.
-
#delete_project_location_instance(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Deletes a single Instance.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Empty
Deletes a long-running operation.
-
#diagnose_instance(name, diagnose_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Creates a Diagnostic File and runs Diagnostic Tool given an Instance.
-
#generate_instance_access_token(name, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::GenerateAccessTokenResponse
Called by VM to return an EUC for the instance owner.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Location
Gets information about a location.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Instance
Gets details of a single Instance.
-
#get_project_location_instance_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Config
Returns various configuration parameters.
-
#get_project_location_instance_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ AIPlatformNotebooksService
constructor
A new instance of AIPlatformNotebooksService.
-
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::ListInstancesResponse
Lists instances in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_instance(name, instance_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
UpdateInstance updates an Instance.
-
#report_project_location_instance_info_system(name, report_instance_info_system_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Allows notebook instances to report their latest instance information to the Notebooks API server.
-
#reset_instance(name, reset_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Resets a notebook instance.
-
#resize_instance_disk(notebook_instance, resize_disk_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Resize a notebook instance disk to a higher capacity.
-
#restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
RestoreInstance restores an Instance from a BackupSource.
-
#rollback_instance(name, rollback_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Rollbacks a notebook instance to the previous version.
-
#set_instance_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Policy
Sets the access control policy on the specified resource.
-
#start_instance(name, start_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Starts a notebook instance.
-
#stop_instance(name, stop_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Stops a notebook instance.
-
#test_instance_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Upgrades a notebook instance to the latest version.
-
#upgrade_project_location_instance_system(name, upgrade_instance_system_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Allows notebook instances to upgrade themselves.
Constructor Details
#initialize ⇒ AIPlatformNotebooksService
Returns a new instance of AIPlatformNotebooksService.
47 48 49 50 51 52 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-notebooks_v2', client_version: Google::Apis::NotebooksV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 966 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:cancel', ) command.request_representation = Google::Apis::NotebooksV2::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::NotebooksV2::Empty::Representation command.response_class = Google::Apis::NotebooksV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#check_instance_authorization(name, check_authorization_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::CheckAuthorizationResponse
Initiated by Cloud Console for Oauth consent flow for Workbench Instances. Do not use this method directly. Design doc: go/wbi-euc:auth-dd
163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 163 def (name, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:checkAuthorization', ) command.request_representation = Google::Apis::NotebooksV2::CheckAuthorizationRequest::Representation command.request_object = command.response_representation = Google::Apis::NotebooksV2::CheckAuthorizationResponse::Representation command.response_class = Google::Apis::NotebooksV2::CheckAuthorizationResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#check_project_location_instance_upgradability(notebook_instance, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::CheckInstanceUpgradabilityResponse
Checks whether a notebook instance is upgradable.
196 197 198 199 200 201 202 203 204 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 196 def check_project_location_instance_upgradability(notebook_instance, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+notebookInstance}:checkUpgradability', ) command.response_representation = Google::Apis::NotebooksV2::CheckInstanceUpgradabilityResponse::Representation command.response_class = Google::Apis::NotebooksV2::CheckInstanceUpgradabilityResponse command.params['notebookInstance'] = notebook_instance unless notebook_instance.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Creates a new Instance in a given project and location.
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 231 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/instances', ) command.request_representation = Google::Apis::NotebooksV2::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Deletes a single Instance.
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 268 def delete_project_location_instance(name, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 1001 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::NotebooksV2::Empty::Representation command.response_class = Google::Apis::NotebooksV2::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#diagnose_instance(name, diagnose_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Creates a Diagnostic File and runs Diagnostic Tool given an Instance.
301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 301 def diagnose_instance(name, diagnose_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:diagnose', ) command.request_representation = Google::Apis::NotebooksV2::DiagnoseInstanceRequest::Representation command.request_object = diagnose_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_instance_access_token(name, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::GenerateAccessTokenResponse
Called by VM to return an EUC for the instance owner. Do not use this method directly. Design doc: go/wbi-euc:dd
336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 336 def generate_instance_access_token(name, generate_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:generateAccessToken', ) command.request_representation = Google::Apis::NotebooksV2::GenerateAccessTokenRequest::Representation command.request_object = generate_access_token_request_object command.response_representation = Google::Apis::NotebooksV2::GenerateAccessTokenResponse::Representation command.response_class = Google::Apis::NotebooksV2::GenerateAccessTokenResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::NotebooksV2::Location::Representation command.response_class = Google::Apis::NotebooksV2::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Instance
Gets details of a single Instance.
369 370 371 372 373 374 375 376 377 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 369 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::NotebooksV2::Instance::Representation command.response_class = Google::Apis::NotebooksV2::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Config
Returns various configuration parameters.
399 400 401 402 403 404 405 406 407 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 399 def get_project_location_instance_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/instances:getConfig', ) command.response_representation = Google::Apis::NotebooksV2::Config::Representation command.response_class = Google::Apis::NotebooksV2::Config command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
443 444 445 446 447 448 449 450 451 452 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 443 def get_project_location_instance_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::NotebooksV2::Policy::Representation command.response_class = Google::Apis::NotebooksV2::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1032 1033 1034 1035 1036 1037 1038 1039 1040 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 1032 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::ListInstancesResponse
Lists instances in a given project and location.
486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 486 def list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/instances', ) command.response_representation = Google::Apis::NotebooksV2::ListInstancesResponse::Representation command.response_class = Google::Apis::NotebooksV2::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 1077 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/operations', ) command.response_representation = Google::Apis::NotebooksV2::ListOperationsResponse::Representation command.response_class = Google::Apis::NotebooksV2::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}/locations', ) command.response_representation = Google::Apis::NotebooksV2::ListLocationsResponse::Representation command.response_class = Google::Apis::NotebooksV2::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
UpdateInstance updates an Instance.
539 540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 539 def patch_project_location_instance(name, instance_object = nil, request_id: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::NotebooksV2::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#report_project_location_instance_info_system(name, report_instance_info_system_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Allows notebook instances to report their latest instance information to the Notebooks API server. The server will merge the reported information to the instance metadata store. Do not use this method directly.
577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 577 def report_project_location_instance_info_system(name, report_instance_info_system_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:reportInfoSystem', ) command.request_representation = Google::Apis::NotebooksV2::ReportInstanceInfoSystemRequest::Representation command.request_object = report_instance_info_system_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#reset_instance(name, reset_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Resets a notebook instance.
611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 611 def reset_instance(name, reset_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:reset', ) command.request_representation = Google::Apis::NotebooksV2::ResetInstanceRequest::Representation command.request_object = reset_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resize_instance_disk(notebook_instance, resize_disk_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Resize a notebook instance disk to a higher capacity.
645 646 647 648 649 650 651 652 653 654 655 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 645 def resize_instance_disk(notebook_instance, resize_disk_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+notebookInstance}:resizeDisk', ) command.request_representation = Google::Apis::NotebooksV2::ResizeDiskRequest::Representation command.request_object = resize_disk_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['notebookInstance'] = notebook_instance unless notebook_instance.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
RestoreInstance restores an Instance from a BackupSource.
679 680 681 682 683 684 685 686 687 688 689 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 679 def restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:restore', ) command.request_representation = Google::Apis::NotebooksV2::RestoreInstanceRequest::Representation command.request_object = restore_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rollback_instance(name, rollback_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Rollbacks a notebook instance to the previous version.
713 714 715 716 717 718 719 720 721 722 723 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 713 def rollback_instance(name, rollback_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:rollback', ) command.request_representation = Google::Apis::NotebooksV2::RollbackInstanceRequest::Representation command.request_object = rollback_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_instance_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
750 751 752 753 754 755 756 757 758 759 760 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 750 def set_instance_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::NotebooksV2::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::NotebooksV2::Policy::Representation command.response_class = Google::Apis::NotebooksV2::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#start_instance(name, start_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Starts a notebook instance.
784 785 786 787 788 789 790 791 792 793 794 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 784 def start_instance(name, start_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:start', ) command.request_representation = Google::Apis::NotebooksV2::StartInstanceRequest::Representation command.request_object = start_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#stop_instance(name, stop_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Stops a notebook instance.
818 819 820 821 822 823 824 825 826 827 828 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 818 def stop_instance(name, stop_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:stop', ) command.request_representation = Google::Apis::NotebooksV2::StopInstanceRequest::Representation command.request_object = stop_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_instance_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 857 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::NotebooksV2::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::NotebooksV2::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::NotebooksV2::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Upgrades a notebook instance to the latest version.
891 892 893 894 895 896 897 898 899 900 901 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 891 def upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:upgrade', ) command.request_representation = Google::Apis::NotebooksV2::UpgradeInstanceRequest::Representation command.request_object = upgrade_instance_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upgrade_project_location_instance_system(name, upgrade_instance_system_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::NotebooksV2::Operation
Allows notebook instances to upgrade themselves. Do not use this method directly.
926 927 928 929 930 931 932 933 934 935 936 |
# File 'lib/google/apis/notebooks_v2/service.rb', line 926 def upgrade_project_location_instance_system(name, upgrade_instance_system_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:upgradeSystem', ) command.request_representation = Google::Apis::NotebooksV2::UpgradeInstanceSystemRequest::Representation command.request_object = upgrade_instance_system_request_object command.response_representation = Google::Apis::NotebooksV2::Operation::Representation command.response_class = Google::Apis::NotebooksV2::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |