Class: Google::Apis::NotebooksV2::CheckInstanceUpgradabilityResponse
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::CheckInstanceUpgradabilityResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
Response for checking if a notebook instance is upgradeable.
Instance Attribute Summary collapse
-
#upgrade_image ⇒ String
The new image self link this instance will be upgraded to if calling the upgrade endpoint.
-
#upgrade_info ⇒ String
Additional information about upgrade.
-
#upgrade_version ⇒ String
The version this instance will be upgraded to if calling the upgrade endpoint.
-
#upgradeable ⇒ Boolean
(also: #upgradeable?)
If an instance is upgradeable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckInstanceUpgradabilityResponse
constructor
A new instance of CheckInstanceUpgradabilityResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckInstanceUpgradabilityResponse
Returns a new instance of CheckInstanceUpgradabilityResponse.
315 316 317 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#upgrade_image ⇒ String
The new image self link this instance will be upgraded to if calling the
upgrade endpoint. This field will only be populated if field upgradeable is
true.
Corresponds to the JSON property upgradeImage
296 297 298 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 296 def upgrade_image @upgrade_image end |
#upgrade_info ⇒ String
Additional information about upgrade.
Corresponds to the JSON property upgradeInfo
301 302 303 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 301 def upgrade_info @upgrade_info end |
#upgrade_version ⇒ String
The version this instance will be upgraded to if calling the upgrade endpoint.
This field will only be populated if field upgradeable is true.
Corresponds to the JSON property upgradeVersion
307 308 309 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 307 def upgrade_version @upgrade_version end |
#upgradeable ⇒ Boolean Also known as: upgradeable?
If an instance is upgradeable.
Corresponds to the JSON property upgradeable
312 313 314 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 312 def upgradeable @upgradeable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
320 321 322 323 324 325 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 320 def update!(**args) @upgrade_image = args[:upgrade_image] if args.key?(:upgrade_image) @upgrade_info = args[:upgrade_info] if args.key?(:upgrade_info) @upgrade_version = args[:upgrade_version] if args.key?(:upgrade_version) @upgradeable = args[:upgradeable] if args.key?(:upgradeable) end |