Class: Google::Apis::NotebooksV2::Config

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Response for getting WbI configurations in a location

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Config

Returns a new instance of Config.



373
374
375
# File 'lib/google/apis/notebooks_v2/classes.rb', line 373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_imagesArray<Google::Apis::NotebooksV2::ImageRelease>

Output only. The list of available images to create a WbI. Corresponds to the JSON property availableImages



354
355
356
# File 'lib/google/apis/notebooks_v2/classes.rb', line 354

def available_images
  @available_images
end

#default_valuesGoogle::Apis::NotebooksV2::DefaultValues

DefaultValues represents the default configuration values. Corresponds to the JSON property defaultValues



359
360
361
# File 'lib/google/apis/notebooks_v2/classes.rb', line 359

def default_values
  @default_values
end

#disable_workbench_legacy_creationBoolean Also known as: disable_workbench_legacy_creation?

Output only. Flag to disable the creation of legacy Workbench notebooks (User- managed notebooks and Google-managed notebooks). Corresponds to the JSON property disableWorkbenchLegacyCreation

Returns:

  • (Boolean)


365
366
367
# File 'lib/google/apis/notebooks_v2/classes.rb', line 365

def disable_workbench_legacy_creation
  @disable_workbench_legacy_creation
end

#supported_valuesGoogle::Apis::NotebooksV2::SupportedValues

SupportedValues represents the values supported by the configuration. Corresponds to the JSON property supportedValues



371
372
373
# File 'lib/google/apis/notebooks_v2/classes.rb', line 371

def supported_values
  @supported_values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



378
379
380
381
382
383
# File 'lib/google/apis/notebooks_v2/classes.rb', line 378

def update!(**args)
  @available_images = args[:available_images] if args.key?(:available_images)
  @default_values = args[:default_values] if args.key?(:default_values)
  @disable_workbench_legacy_creation = args[:disable_workbench_legacy_creation] if args.key?(:disable_workbench_legacy_creation)
  @supported_values = args[:supported_values] if args.key?(:supported_values)
end