Class: Google::Apis::NotebooksV2::DataDisk
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::DataDisk
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#disk_encryption ⇒ String
Optional.
-
#disk_size_gb ⇒ Fixnum
Optional.
-
#disk_type ⇒ String
Optional.
-
#kms_key ⇒ String
Optional.
-
#resource_policies ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataDisk
constructor
A new instance of DataDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataDisk
Returns a new instance of DataDisk.
448 449 450 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_encryption ⇒ String
Optional. Input only. Disk encryption method used on the boot and data disks,
defaults to GMEK.
Corresponds to the JSON property diskEncryption
422 423 424 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 422 def disk_encryption @disk_encryption end |
#disk_size_gb ⇒ Fixnum
Optional. The size of the disk in GB attached to this VM instance, up to a
maximum of 64000 GB (64 TB). If not specified, this defaults to 100.
Corresponds to the JSON property diskSizeGb
428 429 430 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 428 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Optional. Input only. Indicates the type of the disk.
Corresponds to the JSON property diskType
433 434 435 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 433 def disk_type @disk_type end |
#kms_key ⇒ String
Optional. Input only. The KMS key used to encrypt the disks, only applicable
if disk_encryption is CMEK. Format: projects/project_id/locations/location
/keyRings/key_ring_id/cryptoKeys/key_id`Learn more about using your own
encryption keys.
Corresponds to the JSON propertykmsKey`
441 442 443 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 441 def kms_key @kms_key end |
#resource_policies ⇒ Array<String>
Optional. The resource policies to apply to the data disk.
Corresponds to the JSON property resourcePolicies
446 447 448 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 446 def resource_policies @resource_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
453 454 455 456 457 458 459 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 453 def update!(**args) @disk_encryption = args[:disk_encryption] if args.key?(:disk_encryption) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @kms_key = args[:kms_key] if args.key?(:kms_key) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) end |