Class: Google::Apis::NotebooksV2::GenerateAccessTokenResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Response message for generating an EUC for the instance owner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateAccessTokenResponse

Returns a new instance of GenerateAccessTokenResponse.



878
879
880
# File 'lib/google/apis/notebooks_v2/classes.rb', line 878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_tokenString

Short-lived access token string which may be used to access Google APIs. Corresponds to the JSON property access_token

Returns:

  • (String)


858
859
860
# File 'lib/google/apis/notebooks_v2/classes.rb', line 858

def access_token
  @access_token
end

#expires_inFixnum

The time in seconds when the access token expires. Typically that's 3600. Corresponds to the JSON property expires_in

Returns:

  • (Fixnum)


863
864
865
# File 'lib/google/apis/notebooks_v2/classes.rb', line 863

def expires_in
  @expires_in
end

#scopeString

Space-separated list of scopes contained in the returned token. https://cloud. google.com/docs/authentication/token-types#access-contents Corresponds to the JSON property scope

Returns:

  • (String)


869
870
871
# File 'lib/google/apis/notebooks_v2/classes.rb', line 869

def scope
  @scope
end

#token_typeString

Type of the returned access token (e.g. "Bearer"). It specifies how the token must be used. Bearer tokens may be used by any entity without proof of identity. Corresponds to the JSON property token_type

Returns:

  • (String)


876
877
878
# File 'lib/google/apis/notebooks_v2/classes.rb', line 876

def token_type
  @token_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



883
884
885
886
887
888
# File 'lib/google/apis/notebooks_v2/classes.rb', line 883

def update!(**args)
  @access_token = args[:access_token] if args.key?(:access_token)
  @expires_in = args[:expires_in] if args.key?(:expires_in)
  @scope = args[:scope] if args.key?(:scope)
  @token_type = args[:token_type] if args.key?(:token_type)
end