Class: Google::Apis::NotebooksV2::GpuDriverConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

A GPU driver configuration

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GpuDriverConfig

Returns a new instance of GpuDriverConfig.



681
682
683
# File 'lib/google/apis/notebooks_v2/classes.rb', line 681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_gpu_driver_pathString

Optional. Specify a custom Cloud Storage path where the GPU driver is stored. If not specified, we'll automatically choose from official GPU drivers. Corresponds to the JSON property customGpuDriverPath

Returns:

  • (String)


671
672
673
# File 'lib/google/apis/notebooks_v2/classes.rb', line 671

def custom_gpu_driver_path
  @custom_gpu_driver_path
end

#enable_gpu_driverBoolean Also known as: enable_gpu_driver?

Optional. Whether the end user authorizes Google Cloud to install GPU driver on this VM instance. If this field is empty or set to false, the GPU driver won't be installed. Only applicable to instances with GPUs. Corresponds to the JSON property enableGpuDriver

Returns:

  • (Boolean)


678
679
680
# File 'lib/google/apis/notebooks_v2/classes.rb', line 678

def enable_gpu_driver
  @enable_gpu_driver
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



686
687
688
689
# File 'lib/google/apis/notebooks_v2/classes.rb', line 686

def update!(**args)
  @custom_gpu_driver_path = args[:custom_gpu_driver_path] if args.key?(:custom_gpu_driver_path)
  @enable_gpu_driver = args[:enable_gpu_driver] if args.key?(:enable_gpu_driver)
end