Class: Google::Apis::NotebooksV2::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Response for listing notebook instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



1090
1091
1092
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::NotebooksV2::Instance>

A list of returned instances. Corresponds to the JSON property instances



1074
1075
1076
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1074

def instances
  @instances
end

#next_page_tokenString

Page token that can be used to continue listing from the last result in the next list call. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1080
1081
1082
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1080

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. For example, ['projects/ project_id/locations/us-west1-a', 'projects/project_id/locations/us- central1-b']. A ListInstancesResponse will only contain either instances or unreachables, Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1088
1089
1090
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1088

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1095
1096
1097
1098
1099
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1095

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end