Class: Google::Apis::NotebooksV2::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::NotebooksV2::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
1149 1150 1151 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1134 1135 1136 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1134 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::NotebooksV2::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1139 1140 1141 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1139 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
1147 1148 1149 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1147 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1154 1155 1156 1157 1158 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1154 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |