Class: Google::Apis::NotebooksV2::ReportInstanceInfoSystemRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Request for notebook instances to report information to Notebooks API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportInstanceInfoSystemRequest

Returns a new instance of ReportInstanceInfoSystemRequest.



1495
1496
1497
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1495

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eventGoogle::Apis::NotebooksV2::Event

The definition of an Event for a managed / semi-managed notebook instance. Corresponds to the JSON property event



1487
1488
1489
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1487

def event
  @event
end

#vm_idString

Required. The VM hardware token for authenticating the VM. https://cloud. google.com/compute/docs/instances/verifying-instance-identity Corresponds to the JSON property vmId

Returns:

  • (String)


1493
1494
1495
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1493

def vm_id
  @vm_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1500
1501
1502
1503
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1500

def update!(**args)
  @event = args[:event] if args.key?(:event)
  @vm_id = args[:vm_id] if args.key?(:vm_id)
end