Class: Google::Apis::NotebooksV2::ShieldedInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::ShieldedInstanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
A set of Shielded Instance options. See Images using supported Shielded VM features. Not all combinations are valid.
Instance Attribute Summary collapse
-
#enable_integrity_monitoring ⇒ Boolean
(also: #enable_integrity_monitoring?)
Optional.
-
#enable_secure_boot ⇒ Boolean
(also: #enable_secure_boot?)
Optional.
-
#enable_vtpm ⇒ Boolean
(also: #enable_vtpm?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShieldedInstanceConfig
constructor
A new instance of ShieldedInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShieldedInstanceConfig
Returns a new instance of ShieldedInstanceConfig.
1731 1732 1733 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_integrity_monitoring ⇒ Boolean Also known as: enable_integrity_monitoring?
Optional. Defines whether the VM instance has integrity monitoring enabled.
Enables monitoring and attestation of the boot integrity of the VM instance.
The attestation is performed against the integrity policy baseline. This
baseline is initially derived from the implicitly trusted boot image when the
VM instance is created.
Corresponds to the JSON property enableIntegrityMonitoring
1713 1714 1715 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1713 def enable_integrity_monitoring @enable_integrity_monitoring end |
#enable_secure_boot ⇒ Boolean Also known as: enable_secure_boot?
Optional. Defines whether the VM instance has Secure Boot enabled. Secure Boot
helps ensure that the system only runs authentic software by verifying the
digital signature of all boot components, and halting the boot process if
signature verification fails. Disabled by default.
Corresponds to the JSON property enableSecureBoot
1722 1723 1724 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1722 def enable_secure_boot @enable_secure_boot end |
#enable_vtpm ⇒ Boolean Also known as: enable_vtpm?
Optional. Defines whether the VM instance has the vTPM enabled.
Corresponds to the JSON property enableVtpm
1728 1729 1730 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1728 def enable_vtpm @enable_vtpm end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1736 1737 1738 1739 1740 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1736 def update!(**args) @enable_integrity_monitoring = args[:enable_integrity_monitoring] if args.key?(:enable_integrity_monitoring) @enable_secure_boot = args[:enable_secure_boot] if args.key?(:enable_secure_boot) @enable_vtpm = args[:enable_vtpm] if args.key?(:enable_vtpm) end |