Class: Google::Apis::NotebooksV2::UpgradeHistoryEntry
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::UpgradeHistoryEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
The entry of VM image upgrade history.
Instance Attribute Summary collapse
-
#action ⇒ String
Optional.
-
#container_image ⇒ String
Optional.
-
#create_time ⇒ String
Immutable.
-
#framework ⇒ String
Optional.
-
#snapshot ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#target_version ⇒ String
Optional.
-
#version ⇒ String
Optional.
-
#vm_image ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeHistoryEntry
constructor
A new instance of UpgradeHistoryEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeHistoryEntry
Returns a new instance of UpgradeHistoryEntry.
1950 1951 1952 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Optional. Action. Rolloback or Upgrade.
Corresponds to the JSON property action
1907 1908 1909 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1907 def action @action end |
#container_image ⇒ String
Optional. The container image before this instance upgrade.
Corresponds to the JSON property containerImage
1912 1913 1914 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1912 def container_image @container_image end |
#create_time ⇒ String
Immutable. The time that this instance upgrade history entry is created.
Corresponds to the JSON property createTime
1917 1918 1919 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1917 def create_time @create_time end |
#framework ⇒ String
Optional. The framework of this notebook instance.
Corresponds to the JSON property framework
1922 1923 1924 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1922 def framework @framework end |
#snapshot ⇒ String
Optional. The snapshot of the boot disk of this notebook instance before
upgrade.
Corresponds to the JSON property snapshot
1928 1929 1930 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1928 def snapshot @snapshot end |
#state ⇒ String
Output only. The state of this instance upgrade history entry.
Corresponds to the JSON property state
1933 1934 1935 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1933 def state @state end |
#target_version ⇒ String
Optional. Target VM Version, like m63.
Corresponds to the JSON property targetVersion
1938 1939 1940 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1938 def target_version @target_version end |
#version ⇒ String
Optional. The version of the notebook instance before this upgrade.
Corresponds to the JSON property version
1943 1944 1945 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1943 def version @version end |
#vm_image ⇒ String
Optional. The VM image before this instance upgrade.
Corresponds to the JSON property vmImage
1948 1949 1950 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1948 def vm_image @vm_image end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1955 def update!(**args) @action = args[:action] if args.key?(:action) @container_image = args[:container_image] if args.key?(:container_image) @create_time = args[:create_time] if args.key?(:create_time) @framework = args[:framework] if args.key?(:framework) @snapshot = args[:snapshot] if args.key?(:snapshot) @state = args[:state] if args.key?(:state) @target_version = args[:target_version] if args.key?(:target_version) @version = args[:version] if args.key?(:version) @vm_image = args[:vm_image] if args.key?(:vm_image) end |