Class: Google::Apis::NotebooksV2::UpgradeInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Request for upgrading a notebook instance

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeInstanceRequest

Returns a new instance of UpgradeInstanceRequest.



1981
1982
1983
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1981

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_familyString

Optional. The Compute Engine image family resource name to upgrade to. Format: projects/project_id/global/images/family/image_family`If specified, the instance will be upgraded to the latest image in the specified image family, allowing upgrades across image families. If not specified, the instance will be upgraded to the latest image in its current image family. Corresponds to the JSON propertyimageFamily`

Returns:

  • (String)


1979
1980
1981
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1979

def image_family
  @image_family
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1986
1987
1988
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1986

def update!(**args)
  @image_family = args[:image_family] if args.key?(:image_family)
end