Class: Google::Apis::NotebooksV2::VmImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Definition of a custom Compute Engine virtual machine image for starting a notebook instance with the environment installed directly on the VM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmImage

Returns a new instance of VmImage.



2041
2042
2043
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#familyString

Optional. Use this VM image family to find the image; the newest image in this family will be used. Corresponds to the JSON property family

Returns:

  • (String)


2020
2021
2022
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2020

def family
  @family
end

#image_descriptionString

Output only. A human-readable description of the image running on the instance (for example, "Debian 11, Python 3.10"), derived at read time from the image release configuration (the source of truth). Set to "Custom" for unrecognized boot-disk images. Corresponds to the JSON property imageDescription

Returns:

  • (String)


2028
2029
2030
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2028

def image_description
  @image_description
end

#nameString

Optional. Use VM image name to find the image. Corresponds to the JSON property name

Returns:

  • (String)


2033
2034
2035
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2033

def name
  @name
end

#projectString

Required. The name of the Google Cloud project that this VM image belongs to. Format: project_id Corresponds to the JSON property project

Returns:

  • (String)


2039
2040
2041
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2039

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2046
2047
2048
2049
2050
2051
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2046

def update!(**args)
  @family = args[:family] if args.key?(:family)
  @image_description = args[:image_description] if args.key?(:image_description)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
end