Class: Google::Apis::NotebooksV2::AccessConfig
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::AccessConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
An access configuration attached to an instance's network interface.
Instance Attribute Summary collapse
-
#external_ip ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccessConfig
constructor
A new instance of AccessConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AccessConfig
Returns a new instance of AccessConfig.
66 67 68 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 66 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_ip ⇒ String
Optional. An external IP address associated with this instance. Specify an
unused static external IP address available to the project or leave this field
undefined to use an IP from a shared ephemeral IP address pool. If you specify
a static external IP address, it must live in the same region as the zone of
the instance.
Corresponds to the JSON property externalIp
64 65 66 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 64 def external_ip @external_ip end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71 72 73 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 71 def update!(**args) @external_ip = args[:external_ip] if args.key?(:external_ip) end |