Class: Google::Apis::NotebooksV2::Instance
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
The definition of a notebook instance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#disable_proxy_access ⇒ Boolean
(also: #disable_proxy_access?)
Optional.
-
#enable_deletion_protection ⇒ Boolean
(also: #enable_deletion_protection?)
Optional.
-
#enable_managed_euc ⇒ Boolean
(also: #enable_managed_euc?)
Optional.
-
#enable_third_party_identity ⇒ Boolean
(also: #enable_third_party_identity?)
Optional.
-
#gce_setup ⇒ Google::Apis::NotebooksV2::GceSetup
The definition of how to configure a VM instance outside of Resources and Identity.
-
#health_info ⇒ Hash<String,String>
Output only.
-
#health_state ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#instance_owners ⇒ Array<String>
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#proxy_uri ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#third_party_proxy_url ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#upgrade_history ⇒ Array<Google::Apis::NotebooksV2::UpgradeHistoryEntry>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
1038 1039 1040 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Instance creation time.
Corresponds to the JSON property createTime
923 924 925 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 923 def create_time @create_time end |
#creator ⇒ String
Output only. Email address of entity that sent original CreateInstance request.
Corresponds to the JSON property creator
928 929 930 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 928 def creator @creator end |
#disable_proxy_access ⇒ Boolean Also known as: disable_proxy_access?
Optional. If true, the notebook instance will not register with the proxy.
Corresponds to the JSON property disableProxyAccess
933 934 935 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 933 def disable_proxy_access @disable_proxy_access end |
#enable_deletion_protection ⇒ Boolean Also known as: enable_deletion_protection?
Optional. If true, deletion protection will be enabled for this Workbench
Instance. If false, deletion protection will be disabled for this Workbench
Instance.
Corresponds to the JSON property enableDeletionProtection
941 942 943 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 941 def enable_deletion_protection @enable_deletion_protection end |
#enable_managed_euc ⇒ Boolean Also known as: enable_managed_euc?
Optional. Flag to enable managed end user credentials for the instance.
Corresponds to the JSON property enableManagedEuc
947 948 949 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 947 def enable_managed_euc @enable_managed_euc end |
#enable_third_party_identity ⇒ Boolean Also known as: enable_third_party_identity?
Optional. Flag that specifies that a notebook can be accessed with third party
identity provider.
Corresponds to the JSON property enableThirdPartyIdentity
954 955 956 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 954 def enable_third_party_identity @enable_third_party_identity end |
#gce_setup ⇒ Google::Apis::NotebooksV2::GceSetup
The definition of how to configure a VM instance outside of Resources and
Identity.
Corresponds to the JSON property gceSetup
961 962 963 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 961 def gce_setup @gce_setup end |
#health_info ⇒ Hash<String,String>
Output only. Additional information about instance health. Example: healthInfo"
: "docker_proxy_agent_status": "1", "docker_status": "1", "
jupyterlab_api_status": "-1", "jupyterlab_status": "-1", "updated": "2020-10-
18 09:40:03.573409"
Corresponds to the JSON property healthInfo
969 970 971 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 969 def health_info @health_info end |
#health_state ⇒ String
Output only. Instance health_state.
Corresponds to the JSON property healthState
974 975 976 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 974 def health_state @health_state end |
#id ⇒ String
Output only. Unique ID of the resource.
Corresponds to the JSON property id
979 980 981 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 979 def id @id end |
#instance_owners ⇒ Array<String>
Optional. The owner of this instance after creation. Format: alias@example.
com Currently supports one owner only. If not specified, all of the service
account users of your VM instance's service account can use the instance.
Corresponds to the JSON property instanceOwners
986 987 988 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 986 def instance_owners @instance_owners end |
#labels ⇒ Hash<String,String>
Optional. Labels to apply to this instance. These can be later modified by the
UpdateInstance method.
Corresponds to the JSON property labels
992 993 994 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 992 def labels @labels end |
#name ⇒ String
Output only. Identifier. The name of this notebook instance. Format: projects/
project_id/locations/location/instances/instance_id`
Corresponds to the JSON propertyname`
998 999 1000 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 998 def name @name end |
#proxy_uri ⇒ String
Output only. The proxy endpoint that is used to access the Jupyter notebook.
Corresponds to the JSON property proxyUri
1003 1004 1005 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1003 def proxy_uri @proxy_uri end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use for Zone Isolation.
Corresponds to the JSON property satisfiesPzi
1008 1009 1010 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1008 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use for Zone Separation.
Corresponds to the JSON property satisfiesPzs
1014 1015 1016 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1014 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The state of this instance.
Corresponds to the JSON property state
1020 1021 1022 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1020 def state @state end |
#third_party_proxy_url ⇒ String
Output only. The workforce pools proxy endpoint that is used to access the
Jupyter notebook.
Corresponds to the JSON property thirdPartyProxyUrl
1026 1027 1028 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1026 def third_party_proxy_url @third_party_proxy_url end |
#update_time ⇒ String
Output only. Instance update time.
Corresponds to the JSON property updateTime
1031 1032 1033 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1031 def update_time @update_time end |
#upgrade_history ⇒ Array<Google::Apis::NotebooksV2::UpgradeHistoryEntry>
Output only. The upgrade history of this instance.
Corresponds to the JSON property upgradeHistory
1036 1037 1038 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1036 def upgrade_history @upgrade_history end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1043 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @disable_proxy_access = args[:disable_proxy_access] if args.key?(:disable_proxy_access) @enable_deletion_protection = args[:enable_deletion_protection] if args.key?(:enable_deletion_protection) @enable_managed_euc = args[:enable_managed_euc] if args.key?(:enable_managed_euc) @enable_third_party_identity = args[:enable_third_party_identity] if args.key?(:enable_third_party_identity) @gce_setup = args[:gce_setup] if args.key?(:gce_setup) @health_info = args[:health_info] if args.key?(:health_info) @health_state = args[:health_state] if args.key?(:health_state) @id = args[:id] if args.key?(:id) @instance_owners = args[:instance_owners] if args.key?(:instance_owners) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @proxy_uri = args[:proxy_uri] if args.key?(:proxy_uri) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @third_party_proxy_url = args[:third_party_proxy_url] if args.key?(:third_party_proxy_url) @update_time = args[:update_time] if args.key?(:update_time) @upgrade_history = args[:upgrade_history] if args.key?(:upgrade_history) end |