Class: Google::Apis::NotebooksV2::UpgradeHistoryEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

The entry of VM image upgrade history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpgradeHistoryEntry

Returns a new instance of UpgradeHistoryEntry.



1937
1938
1939
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Optional. Action. Rolloback or Upgrade. Corresponds to the JSON property action

Returns:

  • (String)


1894
1895
1896
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1894

def action
  @action
end

#container_imageString

Optional. The container image before this instance upgrade. Corresponds to the JSON property containerImage

Returns:

  • (String)


1899
1900
1901
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1899

def container_image
  @container_image
end

#create_timeString

Immutable. The time that this instance upgrade history entry is created. Corresponds to the JSON property createTime

Returns:

  • (String)


1904
1905
1906
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1904

def create_time
  @create_time
end

#frameworkString

Optional. The framework of this notebook instance. Corresponds to the JSON property framework

Returns:

  • (String)


1909
1910
1911
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1909

def framework
  @framework
end

#snapshotString

Optional. The snapshot of the boot disk of this notebook instance before upgrade. Corresponds to the JSON property snapshot

Returns:

  • (String)


1915
1916
1917
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1915

def snapshot
  @snapshot
end

#stateString

Output only. The state of this instance upgrade history entry. Corresponds to the JSON property state

Returns:

  • (String)


1920
1921
1922
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1920

def state
  @state
end

#target_versionString

Optional. Target VM Version, like m63. Corresponds to the JSON property targetVersion

Returns:

  • (String)


1925
1926
1927
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1925

def target_version
  @target_version
end

#versionString

Optional. The version of the notebook instance before this upgrade. Corresponds to the JSON property version

Returns:

  • (String)


1930
1931
1932
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1930

def version
  @version
end

#vm_imageString

Optional. The VM image before this instance upgrade. Corresponds to the JSON property vmImage

Returns:

  • (String)


1935
1936
1937
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1935

def vm_image
  @vm_image
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1942
1943
1944
1945
1946
1947
1948
1949
1950
1951
1952
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1942

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @container_image = args[:container_image] if args.key?(:container_image)
  @create_time = args[:create_time] if args.key?(:create_time)
  @framework = args[:framework] if args.key?(:framework)
  @snapshot = args[:snapshot] if args.key?(:snapshot)
  @state = args[:state] if args.key?(:state)
  @target_version = args[:target_version] if args.key?(:target_version)
  @version = args[:version] if args.key?(:version)
  @vm_image = args[:vm_image] if args.key?(:vm_image)
end