Class: Google::Apis::NotebooksV2::UpgradeInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::NotebooksV2::UpgradeInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb
Overview
Request for upgrading a notebook instance
Instance Attribute Summary collapse
-
#image_family ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpgradeInstanceRequest
constructor
A new instance of UpgradeInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpgradeInstanceRequest
Returns a new instance of UpgradeInstanceRequest.
1968 1969 1970 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1968 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image_family ⇒ String
Optional. The Compute Engine image family resource name to upgrade to. Format:
projects/project_id/global/images/family/image_family`If specified, the
instance will be upgraded to the latest image in the specified image family,
allowing upgrades across image families. If not specified, the instance will
be upgraded to the latest image in its current image family.
Corresponds to the JSON propertyimageFamily`
1966 1967 1968 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1966 def image_family @image_family end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1973 1974 1975 |
# File 'lib/google/apis/notebooks_v2/classes.rb', line 1973 def update!(**args) @image_family = args[:image_family] if args.key?(:image_family) end |