Class: Google::Apis::NotebooksV2::VmImage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/notebooks_v2/classes.rb,
lib/google/apis/notebooks_v2/representations.rb,
lib/google/apis/notebooks_v2/representations.rb

Overview

Definition of a custom Compute Engine virtual machine image for starting a notebook instance with the environment installed directly on the VM.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmImage

Returns a new instance of VmImage.



2020
2021
2022
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#familyString

Optional. Use this VM image family to find the image; the newest image in this family will be used. Corresponds to the JSON property family

Returns:

  • (String)


2007
2008
2009
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2007

def family
  @family
end

#nameString

Optional. Use VM image name to find the image. Corresponds to the JSON property name

Returns:

  • (String)


2012
2013
2014
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2012

def name
  @name
end

#projectString

Required. The name of the Google Cloud project that this VM image belongs to. Format: project_id Corresponds to the JSON property project

Returns:

  • (String)


2018
2019
2020
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2018

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2025
2026
2027
2028
2029
# File 'lib/google/apis/notebooks_v2/classes.rb', line 2025

def update!(**args)
  @family = args[:family] if args.key?(:family)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
end